==> glibc-2.2.3.tar.gz: glibc-2.2.3/sysdeps/generic/defs.c <==
/* Definitions of global stdio data structures.
   Copyright (C) 1991, 1995, 1997 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the GNU C Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

#include <stdio.h>

/* This file should define the following
   variables as appropriate for the system.  */

FILE *stdin, *stdout, *stderr;

/* Pointer to the first stream in the list.  */
FILE *__stdio_head;

/* This function MUST be in this file!
   This is because we want _cleanup to go into the __libc_atexit set
   when any stdio code is used (and to use any stdio code, one must reference
   something defined in this file), and since only local symbols can be made
   set elements, having the set element stab entry here and _cleanup elsewhere
   loses; and having them both elsewhere loses because there is no reference
   to cause _cleanup to be linked in.  */

void
_cleanup ()
{
  __fcloseall ();
}


#ifdef	HAVE_GNU_LD
text_set_element (__libc_atexit, _cleanup);
#endif

==> glibc-2.2.4.tar.gz: glibc-2.2.4/sysdeps/generic/defs.c <==
/* Definitions of global stdio data structures.
   Copyright (C) 1991, 1995, 1997 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

#include <stdio.h>

/* This file should define the following
   variables as appropriate for the system.  */

FILE *stdin, *stdout, *stderr;

/* Pointer to the first stream in the list.  */
FILE *__stdio_head;

/* This function MUST be in this file!
   This is because we want _cleanup to go into the __libc_atexit set
   when any stdio code is used (and to use any stdio code, one must reference
   something defined in this file), and since only local symbols can be made
   set elements, having the set element stab entry here and _cleanup elsewhere
   loses; and having them both elsewhere loses because there is no reference
   to cause _cleanup to be linked in.  */

void
_cleanup ()
{
  __fcloseall ();
}


#ifdef	HAVE_GNU_LD
text_set_element (__libc_atexit, _cleanup);
#endif
